==> tuia-advert-center-api-2.4.73-sources.jar: cn/com/duiba/tuia/core/api/dto/req/ReqUpdateAuditData.java <==
/**
 * Project Name:tuia-core-api<br>
 * File Name:ReqUpdateAuditData.java<br>
 * Package Name:cn.com.duiba.tuia.core.api.dto.req<br>
 * Date:2016年9月8日下午4:13:36<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.dto.req;

import java.io.Serializable;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: ReqUpdateAuditData <br/>
 * Function: 修改代理商审核材料请求参数. <br/>
 * date: 2016年9月8日 下午4:13:36 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public class ReqUpdateAuditData implements Serializable {

    private static final long serialVersionUID = 1L;

    /** The id. */
    protected Long            id;

    /** 邮箱. */
    private String            email;

    /** 密码. */
    private String            password;

    /** 公司名称. */
    private String            companyName;

    /** 营业执照号. */
    private String            businessLicenseId;

    /** 营业执照名称. */
    private String            businessLicenseName;

    /** 营业执照照片. */
    private String            businessLicenseUrl;

    /** 公司地址. */
    private String            companyAddress;

    /** 联系人姓名. */
    private String            linkman;

    /** 联系人手机号. */
    private String            linkmanPhone;

    /** 联系人QQ. */
    private String            linkmanQQ;

    /** 谷歌验证器秘钥. */
    private String            googleAuthKey;

    /** 代理商公司名. */
    private String            agentCompanyName;

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public String getGoogleAuthKey() {
        return googleAuthKey;
    }

    public void setGoogleAuthKey(String googleAuthKey) {
        this.googleAuthKey = googleAuthKey;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getBusinessLicenseId() {
        return businessLicenseId;
    }

    public void setBusinessLicenseId(String businessLicenseId) {
        this.businessLicenseId = businessLicenseId;
    }

    public String getBusinessLicenseName() {
        return businessLicenseName;
    }

    public void setBusinessLicenseName(String businessLicenseName) {
        this.businessLicenseName = businessLicenseName;
    }

    public String getBusinessLicenseUrl() {
        return businessLicenseUrl;
    }

    public void setBusinessLicenseUrl(String businessLicenseUrl) {
        this.businessLicenseUrl = businessLicenseUrl;
    }

    public String getCompanyAddress() {
        return companyAddress;
    }

    public void setCompanyAddress(String companyAddress) {
        this.companyAddress = companyAddress;
    }

    public String getLinkman() {
        return linkman;
    }

    public void setLinkman(String linkman) {
        this.linkman = linkman;
    }

    public String getLinkmanPhone() {
        return linkmanPhone;
    }

    public void setLinkmanPhone(String linkmanPhone) {
        this.linkmanPhone = linkmanPhone;
    }

    public String getLinkmanQQ() {
        return linkmanQQ;
    }

    public void setLinkmanQQ(String linkmanQQ) {
        this.linkmanQQ = linkmanQQ;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-2.6.11-sources.jar: cn/com/duiba/tuia/core/api/dto/req/ReqUpdateAuditData.java <==
/**
 * Project Name:tuia-core-api<br>
 * File Name:ReqUpdateAuditData.java<br>
 * Package Name:cn.com.duiba.tuia.core.api.dto.req<br>
 * Date:2016年9月8日下午4:13:36<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.dto.req;

import java.io.Serializable;

import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: ReqUpdateAuditData <br/>
 * Function: 修改代理商审核材料请求参数. <br/>
 * date: 2016年9月8日 下午4:13:36 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public class ReqUpdateAuditData implements Serializable {

    private static final long serialVersionUID = 1L;

    /** The id. */
    protected Long            id;

    /** 邮箱. */
    private String            email;

    /** 密码. */
    private String            password;

    /** 公司名称. */
    private String            companyName;

    /** 营业执照号. */
    private String            businessLicenseId;

    /** 营业执照名称. */
    private String            businessLicenseName;

    /** 营业执照照片. */
    private String            businessLicenseUrl;

    /** 公司地址. */
    private String            companyAddress;

    /** 联系人姓名. */
    private String            linkman;

    /** 联系人手机号. */
    private String            linkmanPhone;

    /** 联系人QQ. */
    private String            linkmanQQ;

    /** 谷歌验证器秘钥. */
    private String            googleAuthKey;

    /** 代理商公司名. */
    private String            agentCompanyName;

    /** 广告主真信息真实承诺书 */
    private String guaranteeUrl;

    /** 承诺书名 */
    private String guaranteeName;

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public String getGoogleAuthKey() {
        return googleAuthKey;
    }

    public void setGoogleAuthKey(String googleAuthKey) {
        this.googleAuthKey = googleAuthKey;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getBusinessLicenseId() {
        return businessLicenseId;
    }

    public void setBusinessLicenseId(String businessLicenseId) {
        this.businessLicenseId = businessLicenseId;
    }

    public String getBusinessLicenseName() {
        return businessLicenseName;
    }

    public void setBusinessLicenseName(String businessLicenseName) {
        this.businessLicenseName = businessLicenseName;
    }

    public String getBusinessLicenseUrl() {
        return businessLicenseUrl;
    }

    public void setBusinessLicenseUrl(String businessLicenseUrl) {
        this.businessLicenseUrl = businessLicenseUrl;
    }

    public String getCompanyAddress() {
        return companyAddress;
    }

    public void setCompanyAddress(String companyAddress) {
        this.companyAddress = companyAddress;
    }

    public String getLinkman() {
        return linkman;
    }

    public void setLinkman(String linkman) {
        this.linkman = linkman;
    }

    public String getLinkmanPhone() {
        return linkmanPhone;
    }

    public void setLinkmanPhone(String linkmanPhone) {
        this.linkmanPhone = linkmanPhone;
    }

    public String getLinkmanQQ() {
        return linkmanQQ;
    }

    public void setLinkmanQQ(String linkmanQQ) {
        this.linkmanQQ = linkmanQQ;
    }

    public String getGuaranteeUrl() {
        return guaranteeUrl;
    }

    public void setGuaranteeUrl(String guaranteeUrl) {
        this.guaranteeUrl = guaranteeUrl;
    }

    public String getGuaranteeName() {
        return guaranteeName;
    }

    public void setGuaranteeName(String guaranteeName) {
        this.guaranteeName = guaranteeName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
